AffineTransformationParameters
==============================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: AffineTransformationParameters
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AffineTransformationParameters.offset
      ~AffineTransformationParameters.scale

   .. rubric:: Methods Summary

   .. autosummary::

      ~AffineTransformationParameters.count
      ~AffineTransformationParameters.index

   .. rubric:: Attributes Documentation

   .. autoattribute:: offset
   .. autoattribute:: scale

   .. rubric:: Methods Documentation

   .. automethod:: count
   .. automethod:: index
